@@ -27,7 +27,6 @@ impl IConceptSpecConst for TimeshtWorkingConProv {
     const CONCEPT_CODE: i32 = ExampleConceptConst::ConceptTimeshtWorking as i32;
 }
 
-#[macro_use(crate::impl_concept_prov)]
 crate::impl_concept_prov!(TimeshtWorkingConProv, provider, TimeshtWorkingConSpec);
 
 pub(crate) struct TimeshtWorkingConSpec {
@@ -61,7 +60,6 @@ impl TimeshtWorkingConProv {
     }
 }
 
-#[macro_use(crate::impl_concept_spec)]
 crate::impl_concept_spec!(TimeshtWorkingConSpec, spec);
 
 // AmountBasis		AMOUNT_BASIS
@@ -73,7 +71,6 @@ impl IConceptSpecConst for AmountBasisConProv {
     const CONCEPT_CODE: i32 = ExampleConceptConst::ConceptAmountBasis as i32;
 }
 
-#[macro_use(crate::impl_concept_prov)]
 crate::impl_concept_prov!(AmountBasisConProv, provider, AmountBasisConSpec);
 
 pub(crate) struct AmountBasisConSpec {
@@ -110,7 +107,6 @@ impl AmountBasisConProv {
     }
 }
 
-#[macro_use(crate::impl_concept_spec)]
 crate::impl_concept_spec!(AmountBasisConSpec, spec);
 
 // AmountFixed		AMOUNT_FIXED
@@ -122,7 +118,6 @@ impl IConceptSpecConst for AmountFixedConProv {
     const CONCEPT_CODE: i32 = ExampleConceptConst::ConceptAmountFixed as i32;
 }
 
-#[macro_use(crate::impl_concept_prov)]
 crate::impl_concept_prov!(AmountFixedConProv, provider, AmountFixedConSpec);
 
 pub(crate) struct AmountFixedConSpec {
@@ -156,7 +151,6 @@ impl AmountFixedConProv {
     }
 }
 
-#[macro_use(crate::impl_concept_spec)]
 crate::impl_concept_spec!(AmountFixedConSpec, spec);
 
 // HealthInsbase		HEALTH_INSBASE
@@ -168,7 +162,6 @@ impl IConceptSpecConst for HealthInsbaseConProv {
     const CONCEPT_CODE: i32 = ExampleConceptConst::ConceptHealthInsbase as i32;
 }
 
-#[macro_use(crate::impl_concept_prov)]
 crate::impl_concept_prov!(HealthInsbaseConProv, provider, HealthInsbaseConSpec);
 
 pub(crate) struct HealthInsbaseConSpec {
@@ -202,7 +195,6 @@ impl HealthInsbaseConProv {
     }
 }
 
-#[macro_use(crate::impl_concept_spec)]
 crate::impl_concept_spec!(HealthInsbaseConSpec, spec);
 
 // SocialInsbase		SOCIAL_INSBASE
@@ -214,7 +206,6 @@ impl IConceptSpecConst for SocialInsbaseConProv {
     const CONCEPT_CODE: i32 = ExampleConceptConst::ConceptSocialInsbase as i32;
 }
 
-#[macro_use(crate::impl_concept_prov)]
 crate::impl_concept_prov!(SocialInsbaseConProv, provider, SocialInsbaseConSpec);
 
 pub(crate) struct SocialInsbaseConSpec {
@@ -248,7 +239,6 @@ impl SocialInsbaseConProv {
     }
 }
 
-#[macro_use(crate::impl_concept_spec)]
 crate::impl_concept_spec!(SocialInsbaseConSpec, spec);
 
 // HealthInspaym		HEALTH_INSPAYM
@@ -260,7 +250,6 @@ impl IConceptSpecConst for HealthInspaymConProv {
     const CONCEPT_CODE: i32 = ExampleConceptConst::ConceptHealthInspaym as i32;
 }
 
-#[macro_use(crate::impl_concept_prov)]
 crate::impl_concept_prov!(HealthInspaymConProv, provider, HealthInspaymConSpec);
 
 pub(crate) struct HealthInspaymConSpec {
@@ -297,7 +286,6 @@ impl HealthInspaymConProv {
     }
 }
 
-#[macro_use(crate::impl_concept_spec)]
 crate::impl_concept_spec!(HealthInspaymConSpec, spec);
 
 // SocialInspaym		SOCIAL_INSPAYM
@@ -309,7 +297,6 @@ impl IConceptSpecConst for SocialInspaymConProv {
     const CONCEPT_CODE: i32 = ExampleConceptConst::ConceptSocialInspaym as i32;
 }
 
-#[macro_use(crate::impl_concept_prov)]
 crate::impl_concept_prov!(SocialInspaymConProv, provider, SocialInspaymConSpec);
 
 pub(crate) struct SocialInspaymConSpec {
@@ -346,7 +333,6 @@ impl SocialInspaymConProv {
     }
 }
 
-#[macro_use(crate::impl_concept_spec)]
 crate::impl_concept_spec!(SocialInspaymConSpec, spec);
 
 // TaxingAdvbase		TAXING_ADVBASE
@@ -358,7 +344,6 @@ impl IConceptSpecConst for TaxingAdvbaseConProv {
     const CONCEPT_CODE: i32 = ExampleConceptConst::ConceptTaxingAdvbase as i32;
 }
 
-#[macro_use(crate::impl_concept_prov)]
 crate::impl_concept_prov!(TaxingAdvbaseConProv, provider, TaxingAdvbaseConSpec);
 
 pub(crate) struct TaxingAdvbaseConSpec {
@@ -392,7 +377,6 @@ impl TaxingAdvbaseConProv {
     }
 }
 
-#[macro_use(crate::impl_concept_spec)]
 crate::impl_concept_spec!(TaxingAdvbaseConSpec, spec);
 
 // TaxingAdvpaym		TAXING_ADVPAYM
@@ -404,7 +388,6 @@ impl IConceptSpecConst for TaxingAdvpaymConProv {
     const CONCEPT_CODE: i32 = ExampleConceptConst::ConceptTaxingAdvpaym as i32;
 }
 
-#[macro_use(crate::impl_concept_prov)]
 crate::impl_concept_prov!(TaxingAdvpaymConProv, provider, TaxingAdvpaymConSpec);
 
 pub(crate) struct TaxingAdvpaymConSpec {
@@ -441,7 +424,6 @@ impl TaxingAdvpaymConProv {
     }
 }
 
-#[macro_use(crate::impl_concept_spec)]
 crate::impl_concept_spec!(TaxingAdvpaymConSpec, spec);
 
 // IncomeGross		INCOME_GROSS
@@ -453,7 +435,6 @@ impl IConceptSpecConst for IncomeGrossConProv {
     const CONCEPT_CODE: i32 = ExampleConceptConst::ConceptIncomeGross as i32;
 }
 
-#[macro_use(crate::impl_concept_prov)]
 crate::impl_concept_prov!(IncomeGrossConProv, provider, IncomeGrossConSpec);
 
 pub(crate) struct IncomeGrossConSpec {
@@ -487,7 +468,6 @@ impl IncomeGrossConProv {
     }
 }
 
-#[macro_use(crate::impl_concept_spec)]
 crate::impl_concept_spec!(IncomeGrossConSpec, spec);
 
 // IncomeNetto		INCOME_NETTO
@@ -499,7 +479,6 @@ impl IConceptSpecConst for IncomeNettoConProv {
     const CONCEPT_CODE: i32 = ExampleConceptConst::ConceptIncomeNetto as i32;
 }
 
-#[macro_use(crate::impl_concept_prov)]
 crate::impl_concept_prov!(IncomeNettoConProv, provider, IncomeNettoConSpec);
 
 pub(crate) struct IncomeNettoConSpec {
@@ -539,6 +518,5 @@ impl IncomeNettoConProv {
     }
 }
 
-#[macro_use(crate::impl_concept_spec)]
 crate::impl_concept_spec!(IncomeNettoConSpec, spec);
 
