@@ -1,5 +1,5 @@
 use crate::service_types::concept_code::ConceptCode;
 
-pub(crate) trait IConceptDefine {
+pub trait IConceptDefine {
     fn get_code(&self) -> ConceptCode;
 }
\ No newline at end of file
