@@ -1,7 +1,7 @@
 use std::hash::{Hash, Hasher};
 
 #[derive(Debug, Copy, Clone)]
-pub(crate) struct ContractCode {
+pub struct ContractCode {
     value: i16
 }
 
@@ -22,19 +22,19 @@ impl Eq for ContractCode {
 
 #[allow(dead_code)]
 impl ContractCode {
-    pub(crate) fn zero() -> ContractCode {
+    pub fn zero() -> ContractCode {
         ContractCode::new()
     }
-    pub(crate) fn new() -> ContractCode {
+    pub fn new() -> ContractCode {
         ContractCode { value: 0 }
     }
-    pub(crate) fn get(_value: i16) -> ContractCode {
+    pub fn get(_value: i16) -> ContractCode {
         ContractCode { value: _value }
     }
-    pub(crate) fn get_value(&self) -> i16 {
+    pub fn get_value(&self) -> i16 {
         self.value
     }
-    pub(crate) fn is_valid(&self) -> bool {
+    pub fn is_valid(&self) -> bool {
         self.value != 0
     }
 }
\ No newline at end of file
