@@ -3,7 +3,7 @@ use chrono::{NaiveDate};
 use crate::registry_constants::term_constants::{ITermConstants, TermConstants};
 use crate::service_types::contract_code::ContractCode;
 
-pub(crate) trait IContractTerm {
+pub trait IContractTerm {
     fn get_contract(&self) -> ContractCode;
     fn get_date_from(&self) -> NaiveDate;
     fn get_date_stop(&self) -> NaiveDate;
@@ -13,12 +13,12 @@ pub(crate) trait IContractTerm {
     fn is_active(&self) -> bool;
 }
 
-pub(crate) type ArcContractTerm = Arc<dyn IContractTerm>;
+pub type ArcContractTerm = Arc<dyn IContractTerm>;
 
-pub(crate) type ArcContractTermList = Vec<ArcContractTerm>;
+pub type ArcContractTermList = Vec<ArcContractTerm>;
 
 #[derive(Debug, Copy, Clone)]
-pub(crate) struct ContractTerm {
+pub struct ContractTerm {
     contract: ContractCode,
     date_from: NaiveDate,
     date_stop: NaiveDate,
